﻿#requires -version 3.0

#demo file aging report

#$remote should be an existing PSSession for CHI-FP02
#data might be better on CHI-FP01

Get-WmiObject win32_share -comp chi-fp02

#region 400 days

$sharepath = "c:\shared\sales2"

$days = {
dir $using:SharePath -recurse | 
Select Fullname,CreationTime,LastWriteTime,
@{Name="Age";Expression={(Get-Date)-$_.LastWriteTime}},
@{Name="Days";Expression={[int]((Get-Date)-$_.LastWriteTime).TotalDays}},
@{Name="Owner";Expression={(Get-ACL $_.fullname).Owner}} |
Where {$_.Days -ge 400} | Sort Days -Descending
}

$data = invoke-command $days -session $remote
$data | out-gridview

#endregion

#region Aging Buckets

$buckets = {
#get some other properties in case we want to further
#break down each bucket

$files = dir $using:sharepath -recurse | 
Select Fullname,CreationTime,LastWriteTime,Length,
@{Name="Age";Expression={(Get-Date)-$_.LastWriteTime}},
@{Name="Days";Expression={[int]((Get-Date)-$_.LastWriteTime).TotalDays}}

$hash= @{
Path=$using:sharepath
Over=      ($files | Where {$_.Days -gt 365} | Measure-Object).Count
'365Days'= ($files | Where {$_.Days -gt 180 -AND $_.Days -le 365} | Measure-Object).Count
'180Days'= ($files | Where {$_.Days -gt 90 -AND $_.Days -le 180} | Measure-Object).Count
'90Days'=  ($files | Where {$_.Days -gt 30 -AND $_.Days -le 90} | Measure-Object).Count
'30Days'=  ($files | Where {$_.Days -gt 7 -AND $_.Days -le 30} | Measure-Object).Count
'7Days'=   ($files | Where {$_.Days -gt 0 -AND $_.Days -le 7} | Measure-Object).Count
}
New-Object -TypeName PSObject -Property $hash | 
Select Path,Over,365Days,180Days,90Days,30Days,7Days
}

$data = invoke-command $buckets -Session $remote
$data

#endregion

#region Aging by Year

$year = {
dir $using:sharepath -recurse | 
Select Fullname,LastWriteTime,
@{Name="Age";Expression={(Get-Date)-$_.LastWriteTime}},
@{Name="Year";Expression={$_.LastWriteTime.Year}} | 
Group-Object Year | Sort Name
}

$data = invoke-command $year -Session $remote
$data

#analyze the data
$data | Sort name | 
Select Name,Count,
@{Name="Size";Expression={($_.Group | measure length -sum).Sum}} |
Out-GridView -Title $sharepath


#endregion
