﻿#requires -version 3.0

#demo creating a new file share

$FS = "CHI-FP02"

#region Add Windows Feature

$features = 'FS-FileServer','FS-Data-Deduplication','FS-Resource-Manager'
#remove-windowsfeature -computername $FS -name $features
Add-WindowsFeature -ComputerName $FS -Name $features 

Restart-Computer $FS -force -Wait 

#endregion

#region Create folder

#use a remote command
#create a remoting session
$remote = New-PSSession -ComputerName $FS

$newpath = "C:\Shared\Sales2"
invoke-command {mkdir $using:newpath} -session $remote

#endregion

#region Set folder NTFS permissions

#look at current settings
Invoke-command {
 get-acl $using:newpath | 
 select -expand access | 
 Select IdentityReference,FileSystemRights,AccessControlType
 } -session $remote -HideComputerName

#turn off inheritance
$sb = {
 $acl = Get-ACL -Path $using:newpath
 $access=$acl.Access
 #preserve inherited access rules
 $acl.SetAccessRuleProtection($True,$True)
 Set-Acl $using:newPath $acl
}

Invoke-Command $sb -session $remote

#remove Builtin\Users
$sb = {
 $acl = Get-ACL -Path $using:newpath
 $access=$acl.Access
 [System.Security.Principal.NTAccount]$principal="Builtin\Users"
 $rule=$access | where {$_.IdentityReference -eq $principal}
 
 $rule | foreach {
   $acl.RemoveAccessRuleSpecific($_)
 }
 Set-Acl -path $using:newpath -AclObject $acl 

 (Get-ACL $using:newPath).Access
}

invoke-command -scriptblock $sb -Session $remote

#grant SALES Users modify
$sb = {
 $acl = Get-ACL -Path $using:newpath
 
 [System.Security.Principal.NTAccount]$principal="globomantics\Chicago Sales Users"
 $Right="Modify"
 $rule = new-object System.Security.AccessControl.FileSystemAccessRule($Principal,$Right,"Allow")
 $rule
 $acl.SetAccessRule($rule)
 Set-Acl -path $using:newpath -AclObject $acl
}

invoke-command -scriptblock $sb -Session $remote

#verify
Invoke-command {(Get-ACL $using:newPath).Access} -session $remote

#endregion

#region Create file share

help New-SmbShare -ShowWindow

#create a new CIM Session for the file server
$cimsession = New-CimSession -ComputerName $FS

$shareParams = @{
 Name = "Sales2"
 Path = $newpath
 Description = "Sales Data"
 FullAccess = "globomantics\Domain Admins"
 ChangeAccess = "globomantics\chicago sales users"
 CachingMode = "Documents"
 CIMSession = $cimsession
}

New-SmbShare @shareparams

#verify
Get-SmbShare -CimSession $cimsession

Get-SmbShareAccess -Name Sales2 -CimSession $cimsession |
format-list

<#
 use Set-SMBShare to modify
 or Remove-SMBShare to remove it
#>

#endregion

#region Copy some files for a finished file share
$localSource = "C:\Oven"

invoke-command {
  dir $using:localsource | copy -recurse -Destination $using:newpath -force
 } -session $remote

#endregion
